4ti2: Algebraic, geometric and combinatorial problems on linear spaces
======================================================================

Description
-----------

A software package for algebraic, geometric and combinatorial problems
on linear spaces. Available at https://4ti2.github.io/.

License
-------

4ti2 is released under a GPL v2 license.


Upstream Contact
----------------

- https://4ti2.github.io/

- Raymond Hemmecke, TU Munich, Germany
- Matthias Köppe, UC Davis, CA, USA
